@@ -237,6 +237,8 @@ sub xsdoc2pod
 
 		$package = $pkgdata->{object} if (exists $pkgdata->{object});
 
+		preprocess_pod ($_) foreach (@{$pkgdata->{pods}});
+
 		push @files, {
 			name => $package,
 			file => $pod,
@@ -288,7 +290,7 @@ sub xsdoc2pod
 		$ret = podify_pods ($pkgdata->{pods}, 'post_signals');
 		print "$ret\n\n" if ($ret);
 
-		$ret = podify_enums_and_flags ($pkgdata);	
+		$ret = podify_enums_and_flags ($pkgdata, $package);	
 		print "\n=head1 ENUMS AND FLAGS\n\n$ret" if ($ret);
 
 		$ret = podify_pods ($pkgdata->{pods}, 'post_enums');
@@ -525,6 +527,7 @@ sub podify_signals {
 sub podify_enums_and_flags
 {
 	my $pkgdata = shift;
+	my $package = shift;
 	
 	my %types = ();
 	
@@ -569,6 +572,35 @@ sub podify_enums_and_flags
 		}
 	}
 
+	if ($package)
+	{
+		my @props;
+		eval { @props = Glib::Object::list_properties($package); 1; };
+		foreach my $prop (@props)
+		{
+			next unless ($prop->{type});
+			$name = convert_type ($prop->{type});
+			$types{$name}++;
+		}
+	
+		my @sigs;
+		eval { @sigs = Glib::Type->list_signals ($package); 1; };
+		foreach my $sig (@sigs)
+		{
+			if ($sig->{return_type})
+			{
+				$name = convert_type ($sig->{return_type});
+				$types{$name}++;
+			}
+			foreach (@{$sig->{param_types}})
+			{
+				next unless ($_);
+				$name = convert_type ($_);
+				$types{$name}++;
+			}
+		}
+	}
+
 	my $type;
 	my $ret = '';
 	foreach (sort keys %types)
@@ -591,7 +623,7 @@ sub podify_enums_and_flags
 =item $string = podify_pods ($pods, $position)
 
 Helper function to allow specific placement of generic pod within the auto
-generated pages. Pod sections starting out with =for posistion XXX, where XXX
+generated pages. Pod sections starting out with =for position XXX, where XXX
 is one of the following will be placed at a specified position. In the case of
 pod that is to be placed after a particular section that doesn't exist, that
 pod will be still be placed there.
@@ -896,7 +928,7 @@ sub preprocess_pod
 				else
 				{
 					carp "\n\nunable to open $2 for inclusion, at ".
-					     $_->{filename}.':'.$_->{line};
+					     $pod->{filename}.':'.$pod->{line};
 				}
 			}
 		}
